#!/usr/bin/env python

# unit tests for in-memory database

import unittest
import os

import memdb

class Test(unittest.TestCase):
    def setUp(self):
        pass
    
    def tearDown(self):
        pass

    def testConstruct(self):
        mdb = memdb.Base("foo.db")

    def testFractalModel(self):
        try:
            mdb = memdb.Base("formulas.db")
            mdb.create(
                formulafile=str,
                formulaname=str,
                type=int,
                lastused=int)

            mdb.insert(
                formulafile="gf4d.frm",
                formulaname="Mandelbar",
                type=0,
                lastused=789)

            mdb.insert(
                formulafile="gf4d.frm",
                formulaname="Mandelbrot",
                type=0,
                lastused=789)

            mdb.insert(
                formulafile="gf4d.cfrm",
                formulaname="",
                type=1,
                lastused=789)
            
            mdb.commit()
        finally:
            if os.path.exists("formulas.db"):
                os.remove("formulas.db")
            
    def testFromMain(self):
        "Adapted from the 'if name==main' chunk from original"
        # test on a 1000 record base
        import random
        names = ['pierre','claire','simon','camille','jean',
                 'florence','marie-anne']
        db = memdb.Base('test')
        if os.path.exists('test'):
            os.remove('test')
        db.create(name=unicode,age=int,size=float)
        for i in range(1000):
            db.insert(name=unicode(random.choice(names)),
                 age=random.randint(7,47),size=random.uniform(1.10,1.95))
        db.create_index('age')
        db.commit()
    
        # print 'Record #20 :',db[20]
        # print '\nRecords with age=30 :'
        for rec in db.age[30]:
            # print '%-10s | %2s | %s' %(rec['name'],rec['age'],round(rec['size'],2))
            pass
        db.insert(name=unicode(random.choice(names))) # missing fields
        # print '\nNumber of records with 30 <= age < 33 :',
        # print sum(1 for r in db if 33 > r['age'] >= 30)
    
        d = db.delete([r for r in db if 32> r['age'] >= 30 and r['name']==u'pierre'])
        # print "\nDeleting %s records with name == 'pierre' and 30 <= age < 32" %d
        # print '\nAfter deleting records '
        for rec in db.age[30]:
            # print '%-10s | %2s | %s' %(rec['name'],rec['age'],round(rec['size'],2))
            pass
        
        # print '\n',sum(1 for r in db),'records in the database'
        # print '\nMake pierre uppercase for age > 27'
        for record in ([r for r in db if r['name']=='pierre' and r['age'] >27]) :
            db.update(record,name=u"Pierre")
        # print len([r for r in db if r['name']==u'Pierre']),'Pierre'
        # print len([r for r in db if r['name']==u'pierre']),'pierre'
        # print len([r for r in db if r['name'] in [u'pierre',u'Pierre']]),'p/Pierre'
        # print 'is unicode :',isinstance(db[20]['name'],unicode)
        db.commit()
        db.open()
        # print '\nSame operation after commit + open'
        # print len([r for r in db if r['name']==u'Pierre']),'Pierre'
        # print len([r for r in db if r['name']==u'pierre']),'pierre'
        # print len([r for r in db if r['name'] in [u'pierre',u'Pierre']]),'p/Pierre'
        # print 'is unicode :',isinstance(db[20]['name'],unicode)


def suite():
    return unittest.makeSuite(Test,'test')

if __name__ == '__main__':
    unittest.main(defaultTest='suite')



